@@ -7,7 +7,6 @@ this file are used to modify the path to use for subsequent imports.
 
 import os
 import sys
-import warnings
 
 # the site module must be imported for normal behavior to take place; it is
 # done dynamically so that cx_Freeze will not add all modules referenced by
@@ -15,9 +14,9 @@ import warnings
 __import__("site")
 
 # now locate the pth file to modify the path appropriately
-baseName, ext = os.path.splitext(FILE_NAME)  # noqa: F821
-pathFileName = baseName + ".pth"
-with open(pathFileName) as in_file:
+name, ext = os.path.splitext(sys.executable)
+filename = name + ".pth"
+with open(filename) as in_file:
     sys.path = [s.strip() for s in in_file.read().splitlines()] + sys.path
 
 
